UtilRF class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
buildLightTheme()
→ ThemeData
-
-
dbBackUp(BuildContext context)
→ dynamic
-
-
downloadFile(String url, String storePath, Function onStart, Function onProgress, Function onFinish, Function onError)
→ Future
-
-
geoPosition()
→ dynamic
-
-
getDate()
→ String
-
-
getDateTime()
→ String
-
-
getFormattedDateTime(String rawDateTime)
→ String
-
-
getInitials(String? account_name)
→ String
-
-
getRandomColor()
→ dynamic
-
-
getTime({bool amPm = false})
→ String
-
-
getUUID()
→ dynamic
-
-
libImage(String path, String libName)
→ dynamic
-
-
uploadFile({String? url, File? file, Function? onComplete, String? ssoToken, Function? onError})
→ Future<StreamedResponse>
-