RapidFire
library
Classes
ActionItemsRF
ActiveNotification
Details of an active notification.
AlertStyleWidget
AndroidBitmap <T >
Represents a bitmap on Android.
AndroidFlutterLocalNotificationsPlugin
Android implementation of the local notifications plugin.
AndroidInitializationSettings
Plugin initialization settings for Android.
AndroidNotification
Android specific properties of a RemoteNotification .
AndroidNotificationAction
Mirrors the Action class in AndroidX.
AndroidNotificationActionInput
Mirrors the RemoteInput functionality available in NotificationCompat.
AndroidNotificationChannel
Settings for Android notification channels.
AndroidNotificationChannelGroup
A group of related Android notification channels.
AndroidNotificationDetails
Contains notification details specific to Android.
AndroidNotificationSound
Represents an Android notification sound.
AnimatedContainerRF
Api
ApiPackets
App
AppBarRF
Appcast
The Appcast class is used to download an Appcast, based on the Sparkle
framework by Andy Matuschak.
Documentation: https://sparkle-project.org/documentation/publishing/
An Appcast is an RSS feed with one channel that has a collection of items
that each describe one app version.
AppcastConstants
These constants taken from:
https://github.com/sparkle-project/Sparkle/blob/master/Sparkle/SUConstants.m
AppcastItem
AppConfigurationRF
AppleNotification
Apple specific properties of a RemoteNotification .
AppleNotificationSound
Represents the sound property for AppleNotification
AppOnboardRF
AppStyles
AppThemeStyleRF
ArRelativeDateTime
ArSaMaDzKwTnRelativeDateTime
AssetsLinuxIcon
Represents an icon from the Flutter Assets directory.
Currently the assets directory is data/flutter_assets
which is located on the path relative to the executable file.
AssetsLinuxSound
Represents a sound from the Flutter Assets directory.
AzRelativeDateTime
BackgroundJob
BaseModelParm
Bidi
This provides utility methods for working with bidirectional text. All
of the methods are static, and are organized into a class primarily to
group them together for documentation and discoverability.
BidiFormatter
Bidi stands for Bi-directional text. According to
Wikipedia :
Bi-directional text is text containing text in both text directionalities,
both right-to-left (RTL) and left-to-right (LTR). It generally involves text
containing different types of alphabets, but may also refer to
boustrophedon, which is changing text directionality in each row.
BigPictureStyleInformation
Used to pass the content for an Android notification displayed using the
big picture style.
BigTextStyleInformation
Used to pass the content for an Android notification displayed using the
big text style.
BitmapFilePathAndroidIcon
Represents a file path to a bitmap that should be used for as an icon on
Android.
BnRelativeDateTime
BottomSheetRF
BounceScrollBehavior
ButtonRF
ByteArrayAndroidBitmap
Represents a base64 encoded AndroidBitmap.
ByteArrayAndroidIcon
Represents a bitmap asset belonging to the Flutter application that should
be used for as an icon on Android.
ByteDataLinuxIcon
Represents an icon from a raw image data bytes, see LinuxRawIconData .
C2Chip <T >
Default choice item widget
C2Choice <T >
Choice item
C2ChoiceMemoizer <T >
alias to AsyncMemoizer
C2ChoiceStyle
Choice item style configuration
C2MultiState <T >
State for Single Choice
C2Placeholder
Default placeholder widget
C2SingleState <T >
State for Single Choice
C2Spinner
Default spinner widget
C2State <T >
Chips Choice State
CardActionRF
CardAvatarRF
CarouselOptions
CarouselSlider
CarouselSliderController
CarouselSliderControllerImpl
CarouselSliderState
CheckBoxDialogRF
CheckRadioLabelRF
CheckRF
ChipsChoice <T >
Easy way to provide a single or multiple choice chips
ColorRF
Configuration
Constraints
A specification of the requirements that need to be met before a WorkRequest can run.
By default, WorkRequests do not have any requirements and can run immediately.
By adding requirements, you can make sure that work only runs in certain situations -
for example, when you have an unmetered network and are charging.
ConstRF
ContainerRF
ContentPost
ContentUriAndroidIcon
Represents a content URI that should be used for as an icon on Android.
CsRelativeDateTime
DarwinInitializationSettings
Plugin initialization settings for Darwin-based operating systems
such as iOS and macOS
DarwinNotificationAction
Describes the notification action itself.
DarwinNotificationAttachment
Represents an attachment for a notification on Darwin-based operation
systems such as iOS and macOS
DarwinNotificationAttachmentThumbnailClippingRect
Represents the clipping rectangle used for the thumbnail image.
DarwinNotificationCategory
Corresponds to the UNNotificationCategory type which is used to configure
notification categories and accompanying options.
DarwinNotificationDetails
Configures notification details specific to Darwin-based operation systems
such as iOS and macOS
Data
DatabaseEvent
DatabaseEvent encapsulates a DataSnapshot and possibly also the key of its
previous sibling, which can be used to order the snapshots.
DatabaseReference
DatabaseReference represents a particular location in your Firebase
Database and can be used for reading or writing data to that location.
DataSnapshot
A DataSnapshot contains data from a Firebase Database location.
Any time you read Firebase data, you receive the data as a DataSnapshot.
DataSourceRF <Object >
DateFormat
DateFormat is for formatting and parsing dates in a locale-sensitive
manner.
DatePickerRF
Db
DbConfigurationRF
DefaultStyleInformation
The default Android notification style.
DeRelativeDateTime
DialogItemListTileRF
DialogRF
DrawableResourceAndroidBitmap
Represents a drawable resource belonging to the Android application that
should be used as a bitmap on Android.
DrawableResourceAndroidIcon
Represents a drawable resource belonging to the Android application that
should be used as an icon on Android.
DrawerAncestorRF
DrawerItemRF
DrawerRF
DropdownRF
DropdownTextRF
Dynamic
DynamicField
EmptyRF
EnRelativeDateTime
EsRelativeDateTime
FaIcon
Creates an Icon Widget that works for non-material Icons, such as the
Font Awesome Icons.
FaRelativeDateTime
FetchAllButtonRF
FieldRowRF
FilePathAndroidBitmap
Represents a file path that should be used for a bitmap on Android.
FilePathLinuxIcon
Represents an icon located at the path in the file system.
It сan be either an absolute UNIX path or a file:// URI scheme, for example:
FilterRF
Firebase
The entry point for accessing Firebase.
FirebaseApp
Represents a single Firebase app instance.
FirebaseConfigRF
FirebaseDatabase
The entry point for accessing a Firebase Database. You can get an instance
by calling FirebaseDatabase.instance or FirebaseDatabase.instanceFor().
FirebaseMessaging
The FirebaseMessaging entry point.
FirebaseOptions
The options used to configure a Firebase app.
FirebaseService
A marker interface for Firebase services that can be registered in FirebaseApp .
FlexBarRF
FlutterBitmapAssetAndroidIcon
Represents a bitmap asset belonging to the Flutter application that should
be used for as an icon on Android.
FlutterLocalNotificationsPlatform
The interface that all implementations of flutter_local_notifications must
implement.
FlutterLocalNotificationsPlugin
Provides cross-platform functionality for displaying local notifications.
FlutterLocalNotificationsWindows
The Windows implementation of package:flutter_local_notifications.
FontAwesomeIcons
Icons based on font awesome 7.1.0
FontSizeResolvers
FrRelativeDateTime
FullWindowDialog
FullWindowDialogState
GapRF
GradientRF
GraphItem
GraphRF
GridCardRF
GridViewRF
GridViewRF1
GridViewRFOLD
HexColor1
HiRelativeDateTime
HttpConfigurationRF
HuRelativeDateTime
IBaseModelUpdaterRF
IconDataBrands
IconData for a font awesome brand icon from a code point
IconDataDuotone
IconData for a font awesome duotone icon from a code point. Only works if
duotone icons (font awesome pro) have been installed.
IconDataLight
IconData for a font awesome light icon from a code point. Only works if
light icons (font awesome pro) have been installed.
IconDataRegular
IconData for a font awesome regular icon from a code point
IconDataSharpLight
IconData for a font awesome sharp light icon from a code point. Only works if
thin icons (font awesome pro, v6+) have been installed.
IconDataSharpRegular
IconData for a font awesome sharp regular icon from a code point. Only works if
thin icons (font awesome pro, v6+) have been installed.
IconDataSharpSolid
IconData for a font awesome sharp solid icon from a code point. Only works if
thin icons (font awesome pro, v6+) have been installed.
IconDataSharpThin
IconData for a font awesome sharp thin icon from a code point. Only works if
thin icons (font awesome pro, v6+) have been installed.
IconDataSolid
IconData for a font awesome solid icon from a code point
IconDataThin
IconData for a font awesome thin icon from a code point. Only works if
thin icons (font awesome pro, v6+) have been installed.
IConfigRF
IContainerRFStyle
IDrawerRF
IdRelativeDateTime
IJobWorkerRF
IModelRF
ImplementationStoreDefaults
InboxStyleInformation
Used to pass the content for an Android notification displayed using the
inbox style.
InfoRatingRF
InfoShareRF
InfoWatchRF
InitializationSettings
Settings for initializing the plugin for each platform.
Intl
The Intl class provides a common entry point for internationalization
related tasks. An Intl instance can be created for a particular locale
and used to create a date format via anIntl.date(). Static methods
on this class are also used in message formatting.
IntroRF
IOnboardRF
IOSFlutterLocalNotificationsPlugin
iOS implementation of the local notifications plugin.
IPageOutlineRF
IPeriodicSyncRF
IStoryboardRF
IStyleRF
ISyncRF
ITextFieldRFStyle
ITextRFStyle
IThemeDataRF
ItRelativeDateTime
ITunesSearchAPI
JaRelativeDateTime
Jiffy
Jiffy is a
Flutter (Android, IOS and Web) date time package for
parsing, manipulating, querying and formatting dates
KoRelativeDateTime
LabelRF
LikeRF
LinuxFlutterLocalNotificationsPlugin
A stub implementation to satisfy compilation of multi-platform packages that
depend on flutter_local_notifications_linux.
This should never actually be created.
LinuxInitializationSettings
Plugin initialization settings for Linux.
LinuxNotificationAction
Represents an action, that send a request message back to the notification
client when invoked. This functionality may not be implemented by the
notification server, conforming clients should check if it's available using
LinuxServerCapabilities .
For more information, please see Desktop Notifications Specification https://specifications.freedesktop.org/notification-spec/latest/ar01s02.html
LinuxNotificationDetails
Configures notification details specific to Linux.
The system may not support all features.
LinuxNotificationIcon
Represents Linux notification icon.
LinuxNotificationLocation
Represents the location on the screen that the notification should point to.
LinuxNotificationSound
Represents Linux notification sound.
LinuxNotificationTimeout
The timeout of the Linux notification.
LinuxRawIconData
Represents an icon in the raw image data.
LinuxServerCapabilities
Represents capabilities, implemented by the Linux notification server.
ListCardRF
ListViewRF
ListViewSliderRF
MacOSFlutterLocalNotificationsPlugin
macOS implementation of the local notifications plugin.
Mapper
MediaStyleInformation
Used to pass the content for an Android notification displayed using the
media style.
Message
Represents a message used in Android messaging style notifications.
MessagingStyleInformation
Used to pass the content for an Android notification displayed using the
messaging style.
MicroMoney
Used primarily for currency formatting, this number-like class stores
millionths of a currency unit, typically as an Int64.
MockUpgraderDevice
MockUpgraderOS
A class to mock UpgraderOS for testing.
ModelObject
ModelRF
Models
ModelsConfigurationRF
MsixUtils
Helpful methods to support MSIX and package identity.
NbRelativeDateTime
NlRelativeDateTime
NotificationAppLaunchDetails
Contains details on the notification that launched the application.
NotificationDetails
Contains notification details specific to each platform.
NotificationResponse
Details of a Notification Action that was triggered.
NotificationsEnabledOptions
Data class that represent current state of notification options.
NotificationSettings
Represents the devices notification settings.
NumberFormat
Provides the ability to format a number in a locale-specific way.
NumberParserBase <R >
Onboard
OnDisconnect
The onDisconnect class allows you to write or clear data when your client
disconnects from the Database server. These updates occur whether your
client disconnects cleanly or not, so you can rely on them to clean up data
even if a connection is dropped or a client crashes.
Ordinals
Outline
OutlineRF
PageAction
PageBuilderRF
PageBuilderRFState
PageConfigurationRF
PageImplementationStoreDefaults
PageParentRF
PageSubTitleRF
PageTitleRF
PageViewSliderRF
PendingNotificationRequest
Details of a pending notification that has not been delivered.
PeriodicSyncRF
Permission
Defines the permissions which can be checked and requested.
PermissionWithService
A special kind of permission, used to access a service.
Person
Details of a person e.g. someone who sent a message.
PlaceholderRF
PlayStoreSearchAPI
PlRelativeDateTime
PtRelativeDateTime
Query
Represents a query over the data at a particular location.
RadioCheckData
RadioRF
RapidFire
RapidFireAppParentRF
RapidFireAppRF
RatingRF
RawResourceAndroidNotificationSound
Represents a raw resource belonging to the Android application that should
be used for the notification sound.
RebuildFactors
REdgeInsets
REdgeInsetsDirectional
RelativeDateTime
RemoteMessage
A class representing a message sent from Firebase Cloud Messaging.
RemoteNotification
A class representing a notification which has been constructed and sent to the
device via FCM.
Res
ResponseRF
RipplesRF
RowRF
RPadding
RSizedBox
RuRelativeDateTime
SaveRF
ScaffoldStoreDefaults
ScaffoldStoreDefaultsApp
ScaffoldStoreDefaultsWidgets
ScaffoldStoreDefaultsWidgetsTabBar
ScreenRF
ScreenUtil
ScreenUtilInit
ServerValue
ServiceRF
ShadowRF
ShareRF
SkRelativeDateTime
SliderRF
SocialRF
SpeedDial
Builds the Speed Dial
SpeedDialChild
Provides data for a speed dial child
SplashRF
StoreOutlineDefaults
StoreRF
StoryboardRF
StyleContainerRF
StyleInformation
Abstract class for defining an Android notification style
StyleStoreDefaults
StyleTextRF
SvRelativeDateTime
SwitchRF
SyncAllButtonRF
SyncFetchRF
TabBarRF
TabBuilderRF
TabControllerRF
TabDesignerRF
TabRF
TemplateRF
TextDirection
Represents directionality of text.
TextFieldRF
TextRF
ThemeLinuxIcon
Represents a system theme icon.
See https://www.freedesktop.org/wiki/Specifications/icon-naming-spec/ for more help.
ThemeLinuxSound
Represents a system theme sound.
See https://www.freedesktop.org/wiki/Specifications/sound-theme-spec/ for more help.
ThemeRF
ThRelativeDateTime
TimePickerRF
Transaction
The pending result of a TransactionHandler .
TransactionResult
Instances of this class represent the outcome of a transaction.
TrRelativeDateTime
UkRelativeDateTime
UpgradeAlert
A widget to display the upgrade dialog.
Override the createState method to provide a custom class
with overridden methods.
UpgradeAlertState
The UpgradeAlert widget state.
UpgradeCard
A widget to display the upgrade card.
The only reason this is a StatefulWidget and not a StatelessWidget is that
the widget needs to rebulid after one of the buttons have been tapped.
Override the createState method to provide a custom class
with overridden methods.
UpgradeCardState
The UpgradeCard widget state.
Upgrader
An upgrade controller that maintains a state that is used to
trigger an alert or other UI to evaluate upgrading criteria.
UpgraderAppcastStore
UpgraderAppStore
UpgraderDevice
UpgraderMessages
The default localized messages used for display in upgrader. Extend this
class to provide custom values and new localizations for languages.
An example to replace the Ignore button with a custom value would be:
UpgraderOS
A class that indicates which OS this code is running on.
UpgraderPlayStore
UpgraderState
The Upgrader state.
UpgraderStore
UpgraderStoreController
A controller that provides the store details for each platform.
UpgraderVersionInfo
UriAndroidNotificationSound
Represents a URI on the Android device that should be used for the
notification sound.
UtilRF
VideoPlayerRF
WebNotification
Web specific properties of a RemoteNotification .
WidgetsRF
WidgetStyleRF
WindowsAction
A button in a Windows notification.
WindowsColumn
A vertical column of text and images in a Windows notification.
A header that groups multiple Windows notifications.
WindowsImage
An image in a Windows notification.
WindowsInitializationSettings
Plugin initialization settings for Windows.
WindowsInput
A text or multiple choice input element in a Windows notification.
WindowsNotificationAudio
Specifies custom audio to play during a notification.
WindowsNotificationDetails
Contains notification details specific to Windows.
WindowsNotificationPart
A text or image element in a Windows notification.
WindowsNotificationText
Text in a Windows notification.
WindowsProgressBar
A progress bar in a Windows notification.
WindowsRow
A group of notification content that must be displayed as a whole row.
WindowsSelection
An option that can be selected by a WindowsSelectionInput .
WindowsSelectionInput
A multiple choice input.
WindowsTextInput
A text input.
Workmanager
Make sure you followed the platform setup steps first before trying to register any task.
WorkmanagerPlatform
The interface that implementations of workmanager must implement.
ZhCnRelativeDateTime
ZhRelativeDateTime
Functions
ambiguate <T > (T? value )
→ T?
This allows a value of type T or T? to be treated as a value of type T?.
drawerContentPage (Animation <double > animation , dynamic scaleAnimation , Animation <BorderRadius ? > ? radiusAnimation , AnimationController animationController , BuildContext context , Widget mainPage )
→ Widget
fab (Function onPressed )
→ Widget
getMappedHost (String originalHost )
→ String
isAlreadyFetched (String tableName , int pageNo )
→ dynamic
notify (String title , String description )
→ dynamic
notifyServiceCompleted (String serviceName )
→ dynamic
openAppSettings ()
→ Future <bool >
Opens the app settings page.
resetServiceFetch (String serviceName )
→ dynamic
resetServiceSync (String serviceName )
→ dynamic
startService (String jobName , Function callback , Map <String , dynamic > ? inputData )
→ dynamic
toBeginningOfSentenceCase <T extends String ? > (T input , [String ? locale ])
→ T
Convert a string to beginning of sentence case, in a way appropriate to the
locale.
typeOfElementsInList <T > (List <T > e )
→ Type
watchFetchCompleted (String serviceName )
→ dynamic
watchServiceCompleted (String serviceName )
→ dynamic
Typedefs
AsyncChildrenBuilder
= Future <List <SpeedDialChild > > Function(BuildContext context )
BackgroundMessageHandler
= Future <void > Function(RemoteMessage message )
Defines a handler for incoming remote message payloads.
BackgroundTaskHandler
= Future <bool > Function(String taskName , Map <String , dynamic > ? inputData )
Function that executes your background work.
You should return whether the task ran successfully or not.
BoolCallback
= bool Function()
Signature of callbacks that have no arguments and return bool.
C2Builder <T >
= Widget ? Function(C2Choice <T > item )
Builder for custom choice item
C2Changed <T >
= void Function(T value )
Callback when the value changed
C2ChoiceLoader <T >
= Future <List <C2Choice <T > > > Function()
Callback to load the choice items
DidReceiveBackgroundNotificationResponseCallback
= void Function(NotificationResponse details )
Signature of callback triggered on background isolate when a user taps on a
notification or a notification action.
DidReceiveLocalNotificationCallback
= void Function(int id , String ? title , String ? body , String ? payload )
Signature of the callback that is triggered when a notification is shown
whilst the app is in the foreground.
DidReceiveNotificationResponseCallback
= void Function(NotificationResponse details )
Signature of callback triggered on main isolate when a user taps on a
notification or a notification action.
ExtendedIndexedWidgetBuilder
= Widget Function(BuildContext context , int index , int realIndex )
FontSizeResolver
= double Function(num fontSize , ScreenUtil instance )
GridBuild
= Widget Function(BuildContext context , int index )
ListViewBuilder <T >
= Widget ? Function(dynamic model , int index )
RebuildFactor
= bool Function(MediaQueryData old , MediaQueryData data )
ScreenUtilInitBuilder
= Widget Function(BuildContext context , Widget ? child )
TransactionHandler
= Transaction Function(Object ? value )
Interface for TransactionHandler
VoidBoolCallback
= void Function(bool value )
Signature of callbacks that have a bool argument and no return.
WillDisplayUpgradeCallback
= void Function({required bool display , String ? installedVersion , UpgraderVersionInfo ? versionInfo })
Signature of callback for willDisplayUpgrade. Includes display,
installedVersion, and versionInfo.