FaDuotoneIconData class final

FaIconData for a font awesome duotone icon.

Duotone icons consist of a primary and a secondary layer.

Annotations

Constructors

FaDuotoneIconData({required IconData primary, required IconData secondary})
Creates a duotone icon data.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
primary IconData
The primary layer of the icon.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary IconData
The secondary layer of the icon.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override