RapidFire class

Constructors

RapidFire(IConfigRF configuration, Function reflectionAgent, {required Api api, Widget? startupPage, bool globalErrorEnabled = true, bool enableNotification = true, dynamic onChatReceived})

Properties

accessControl AccessControl?
getter/setter pair
addNotification bool?
getter/setter pair
api Api
getter/setter pair
app App?
getter/setter pair
appUser AppUser?
getter/setter pair
channel AndroidNotificationChannel
getter/setter pair
context BuildContext
getter/setter pair
db Db
getter/setter pair
debugOptions ↔ Catcher2Options?
getter/setter pair
flush ↔ Flushbar
getter/setter pair
flutterLocalNotificationsPlugin FlutterLocalNotificationsPlugin?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
http HttpRF
getter/setter pair
lang Res?
getter/setter pair
mapper Mapper?
getter/setter pair
model ModelObject?
getter/setter pair
models Map<String, dynamic>?
getter/setter pair
network NetworkRF
getter/setter pair
onboard AppOnboardRF?
getter/setter pair
onChatReceived Function?
getter/setter pair
onMemberRemoved Function?
getter/setter pair
onMessageReceive Function?
getter/setter pair
page PageAction
getter/setter pair
post ContentPost
getter/setter pair
pref ↔ SharedPreferences?
getter/setter pair
rdb Rdb?
getter/setter pair
releaseOptions ↔ Catcher2Options?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style AppStyles?
getter/setter pair
worker IJobWorkerRF
getter/setter pair

Methods

addFcmListener() → dynamic
getFcmTocken() → dynamic
initFirebase() → dynamic
msg(BuildContext context, String text, {MessageType type = MessageType.info, IconData? icon, Color color = Colors.black87, Color backgroundColor = Colors.redAccent, String actionText = '', Function? action, Duration duration = const Duration(seconds: 2)}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run([dynamic callback]) Future
startPeriodicSync(IPeriodicSyncRF dispatcher, dynamic interval) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

catcher ↔ Catcher2?
getter/setter pair

Static Methods

globalErrorMessage() → dynamic
updateGlobalErrorLanguage() → dynamic