Frequency enum
Enum for specifying the frequency at which periodic work repeats.
Values
- never → const Frequency
-
When no frequency is given.
- min15minutes → const Frequency
-
Work repeats with a minimal interval of 15 minutes.
- min30minutes → const Frequency
-
Work repeats with an interval of 30 minutes.
- hourly → const Frequency
-
Work repeats with an interval of 1 hour.
- sixHourly → const Frequency
-
Work repeats with an interval of 6 hours.
- twelveHourly → const Frequency
-
Work repeats with an interval of 12 hours.
- daily → const Frequency
-
Work repeats with an interval of 1 day.
- weekly → const Frequency
-
Work repeats with an interval of 1 week.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited